<?php 
class controller_block_comments_form extends block {
	protected $errors = array();
	
	public function action_index($block) {
		$this->load_model('component', 'comments');
		
		$component_comments_config = $this->get_component_config('comments');
		
		$user = $this->get_global_data('user');
		
		$page_id = $this->get_global_data('page_id');
		
		$data = array();
		
		if (isset($_POST['add_comment']) && $this->validate()) {
			$comment_data = array(
				'page_id'    => $page_id,
				'url'        => $this->url['request_uri'],
				'text'       => $this->helper_validate->safestr($_POST['comment_text'], true),
				'date_add'   => time()
			);
			
			if ($user) {
				$comment_data['user_name'] = $user['login'];
				$comment_data['user_email'] = $user['email'];
			} else {
				$comment_data['user_name'] = $this->helper_validate->safestr($_POST['comment_user_name']);
				
				if ($component_comments_config['email_required']) {
					$comment_data['user_email'] = $this->helper_validate->safestr($_POST['comment_user_email']);
				} else {
					$comment_data['user_email'] = '';
				}
			}
			
			if (isset($_POST['comment_user_site'])) {
				$comment_data['user_site'] = $this->helper_validate->safestr($_POST['comment_user_site']);
			} else {
				$comment_data['user_site'] = '';
			}
			
			$this->model->add_comment($comment_data);
			
			$_SESSION['comment_add_success'] = 'Комментарий добавлен';
			$this->redirect(SITE_URL . $this->url['request_uri']);
		}
		
		if (isset($_POST['comment_user_name'])) {
			$this->data['user_name'] = $_POST['comment_user_name'];
		} else {
			$this->data['user_name'] = '';
		}
		
		if (isset($_POST['comment_user_email'])) {
			$this->data['user_email'] = $_POST['comment_user_email'];
		} else {
			$this->data['user_email'] = '';
		}
		
		if (isset($_POST['comment_user_site'])) {
			$this->data['user_site'] = $_POST['comment_user_site'];
		} else {
			$this->data['user_site'] = '';
		}
		
		if (isset($_POST['comment_text'])) {
			$this->data['text'] = $_POST['comment_text'];
		} else {
			$this->data['text'] = '';
		}
		
		if ($page_id) {
			$data['page_id'] = $page_id;
		} else {
			$data['url'] = $this->url['request_uri'];
		}
		
		$this->data['comments'] = array();
		
		$comments = $this->model_component_comments->get_comments($data);
		
		foreach ($comments as $comment) {
			$this->data['comments'][] = array(
				'user_name'  => $comment['user_name'],
				'user_email' => $comment['user_email'],
				'user_site'  => $comment['user_site'],
				'text'       => $comment['text'],
				'date_add'   => date('d.m.Y H:i', $comment['date_add'])
			);
		}
		
		if (isset($_SESSION['comment_add_success'])) {
			$this->data['success'] = $_SESSION['comment_add_success'];
			unset($_SESSION['comment_add_success']);
		} else {
			$this->data['success'] = false;
		}

		$this->data['errors'] = $this->errors;
		$this->data['user'] = $user;
		$this->data['show_email_field'] = $component_comments_config['show_email_field'];
		$this->data['show_site_field'] = $component_comments_config['show_site_field'];
		
		$this->page['head'] = $this->add_css_file(SITE_URL . '/modules/blocks/' . $this->block_name . '/views/style.css');
		$this->page['html'] = $this->load_view();
		
		return $this->page;
	}
	
	protected function validate() {
		$this->load_helper('validate');
		$component_comments_config = $this->get_component_config('comments');
		$user = $this->get_global_data('user');
		
		if (!$user) {
			if (!isset($_POST['comment_user_name']) || empty($_POST['comment_user_name'])) {
				$this->errors[] = 'Укажите ваше имя';
			}
				
			if ($component_comments_config['email_required']) {
				if (!isset($_POST['comment_user_email']) || empty($_POST['comment_user_email'])) {
					$this->errors[] = 'Укажите ваш email';
				} elseif (!$this->helper_validate->email($_POST['comment_user_email'])) {
					$this->errors[] = 'Некорректный email';
				}
			}
		}
		
		if ($component_comments_config['site_required'] && (!isset($_POST['comment_user_site']) || empty($_POST['comment_user_site']))) {
			$this->errors[] = 'Укажите ваш сайт';
		}
		
		if (!isset($_POST['comment_text']) || empty($_POST['comment_text'])) {
			$this->errors[] = 'Введите текст комментария';
		}
		
		if ($this->errors) {
			return false;
		} else {
			return true;
		}
		
	}
		
	public function action_activate() {
		
	}
	
	public function action_deactivate() {
		
	}
	
	public function action_settings() {
		
	}
}